@@ -618,15 +618,15 @@ ct_colors = function(ct)
 #' @importFrom ComplexHeatmap anno_barplot
 #' @importFrom ComplexHeatmap anno_lines
 type_to_annot_function = list(
-  "tile" = NULL, 
+  "tile" = NULL, #anno_simple, 
   "point" = anno_points, 
   "bar" = anno_barplot, 
   "line" = anno_lines
 )
 
-get_top_left_annotation = function(.data_, .column, .row, .abundance, annotation, palette_annotation, type, x_y_annot_cols){
+get_top_left_annotation = function(.data_, .column, .row, .abundance, annotation, palette_annotation, type, x_y_annot_cols, size, ...){
   
-  # Comply with CRAN NOTES
+  # Comply with CRAN NOTES 
   data = NULL
   fx = NULL
   annot = NULL
@@ -643,93 +643,108 @@ get_top_left_annotation = function(.data_, .column, .row, .abundance, annotation
   .abundance = enquo(.abundance)
   annotation = enquo(annotation)
   
+  dots_args = rlang::dots_list(...)
+  
   annotation_function = type_to_annot_function[type]
   
   # Create dataset
   quo_names(annotation) %>%
-  as_tibble %>%
-  rename(col_name = value) %>%
-  
-  # delete if annotation is NULL
-  when(quo_is_null(annotation) ~ slice(., 0), ~ (.)) %>%
-  
-  # Add orientation
-  left_join(x_y_annot_cols,  by = "col_name") %>%
-  mutate(col_orientation = map_chr(orientation, ~ .x %>% when((.) == "column" ~ quo_name(.column), (.) == "row" ~ quo_name(.row)))) %>%
-  
-  # Add data
-  mutate(
-    data = map2(
-      col_name,
-      col_orientation,
-      ~
-        .data_ %>%
-        ungroup() %>%
-        select(.y, .x) %>%
-        distinct() %>%
-        arrange_at(vars(.y)) %>%
-        pull(.x)
-    )
-  )  %>%
-    
-  # Add function
-  mutate(fx = annotation_function) %>%
-  
-  # Apply annot function if not NULL otherwise pass original annotation
-  # This because no function for ComplexHeatmap = to tile
-  mutate(annot = pmap(list(data, fx, orientation), ~  {
-    
-    # Trick needed for map BUG: could not find function "..2"
-    fx = ..2
-    
-    # Do conditional
-    if(is_function(fx)) fx(..1, which=..3) 
-    else .x
-  })) %>%
-  
-  # # Check if NA in annotations
-  # mutate_at(vars(!!annotation), function(x) {
-  # 	if(any(is.na(x))) { warning("tidyHeatmap says: You have NAs into your annotation column"); replace_na(x, "NA"); } 
-  # 	else { x } 
-  # } ) %>% 
-  
-  # Add color indexes separately for each orientation
-  mutate(annot_type = map_chr(annot, ~ .x %>% when(class(.) %in% c("factor", "character", "logical") ~ "discrete",
-                                                   class(.) %in% c("integer", "numerical", "numeric", "double") ~ "continuous",
-                                                   ~ "other"
-  ) )) %>%
-  group_by(annot_type) %>%
-  mutate(idx =  row_number()) %>%
-  ungroup() %>%
-  mutate(color = map2(annot, idx,  ~ {
-    if(.x %>% class %in% c("factor", "character", "logical"))
-      colorRampPalette(palette_annotation$discrete[[.y]])(length(unique(.x))) %>% setNames(unique(.x))
-    else if (.x %>% class %in% c("integer", "numerical", "numeric", "double"))
-      colorRampPalette(palette_annotation$continuous[[.y]])(length(.x)) %>% colorRamp2(seq(min(.x), max(.x), length.out = length(.x)), .)
-    else NULL
-  })) %>%
-  
-  # Stop if annotations discrete bigger than palette
-  when(
-    (.) %>%  pull(data) %>% map_chr(~ .x %>% class) %in% 
-      c("factor", "character") %>% which %>% length %>%
-      gt(palette_annotation$discrete %>% length) ~
-      stop("tidyHeatmap says: Your discrete annotaton columns are bigger than the palette available"),
-    ~ (.)
-  ) %>%
-  
-  # Stop if annotations continuous bigger than palette
-  when(
-    (.) %>%  pull(data) %>% map_chr(~ .x %>% class) %in% 
-      c("int", "dbl", "numeric") %>% which %>% length %>%
-      gt( palette_annotation$continuous %>% length) ~
-      stop("tidyHeatmap says: Your continuous annotaton columns are bigger than the palette available"),
-    ~ (.)
-  )
+	  as_tibble %>%
+	  rename(col_name = value) %>%
+	  
+	  # delete if annotation is NULL
+	  when(quo_is_null(annotation) ~ slice(., 0), ~ (.)) %>%
+	  
+	  # Add orientation
+	  left_join(x_y_annot_cols,  by = "col_name") %>%
+	  mutate(col_orientation = map_chr(orientation, ~ .x %>% when((.) == "column" ~ quo_name(.column), (.) == "row" ~ quo_name(.row)))) %>%
+	  
+	  # Add data
+	  mutate(
+	    data = map2(
+	      col_name,
+	      col_orientation,
+	      ~
+	        .data_ %>%
+	        ungroup() %>%
+	        select(.y, .x) %>%
+	        distinct() %>% 
+	        arrange_at(vars(.y)) %>%
+	        pull(.x)
+	    )
+	  )  %>%
+	    
+	  # Add function
+	  mutate(fx = annotation_function) %>%
+	  
+	
+	  	
+	  # Apply annot function if not NULL otherwise pass original annotation
+	  # This because no function for ComplexHeatmap = to tile
+	  mutate(annot = pmap(list(data, fx, orientation), ~  {
+	    
+	    # Trick needed for map BUG: could not find function "..2"
+	    fx = ..2
+	    
+	    # Do conditional
+	    if(is_function(fx) & ..3 == "column") fx(..1, which=..3, height = size) 
+	    else if(is_function(fx) & ..3 == "row") fx(..1, which=..3, width = size) 
+	    else .x # else stop("tidyHeatmap says: this should not happen. In the internal function get_top_left_annotation")
+	  })) %>%
+	  
+	  # # Check if NA in annotations
+	  # mutate_at(vars(!!annotation), function(x) {
+	  # 	if(any(is.na(x))) { warning("tidyHeatmap says: You have NAs into your annotation column"); replace_na(x, "NA"); } 
+	  # 	else { x } 
+	  # } ) %>% 
+	  
+		# Add color indexes separately for each orientation
+		mutate(annot_type = map_chr(annot, ~ .x %>% when(class(.) %in% c("factor", "character", "logical") ~ "discrete",
+																										class(.) %in% c("integer", "numerical", "numeric", "double") ~ "continuous",
+																										~ "other"
+		) )) %>%
+		group_by(annot_type) %>%
+		mutate(idx =  row_number()) %>%
+		ungroup() %>%
+		mutate(color = map2(annot, idx,  ~ {
+			if(.x %>% class %in% c("factor", "character", "logical"))
+				colorRampPalette(palette_annotation$discrete[[.y]])(length(unique(.x))) %>% setNames(unique(.x))
+			else if (.x %>% class %in% c("integer", "numerical", "numeric", "double"))
+				colorRampPalette(palette_annotation$continuous[[.y]])(length(.x)) %>% colorRamp2(seq(min(.x), max(.x), length.out = length(.x)), .)
+			else NULL
+		})) %>%
+	  	
+	  mutate(further_arguments = map2(
+	  	col_name, fx,
+	  	~ dots_args %>% 
+	  		
+	  		# If tile add size as further argument
+	  		when(!is_function(.y) ~ c(., list(simple_anno_size = size)), ~ (.))
+	  		
+	  )) %>% 	
+	  
+	  # Stop if annotations discrete bigger than palette
+	  when(
+	    (.) %>%  pull(data) %>% map_chr(~ .x %>% class) %in% 
+	      c("factor", "character") %>% which %>% length %>%
+	      gt(palette_annotation$discrete %>% length) ~
+	      stop("tidyHeatmap says: Your discrete annotaton columns are bigger than the palette available"),
+	    ~ (.)
+	  ) %>%
+	  
+	  # Stop if annotations continuous bigger than palette
+	  when(
+	    (.) %>%  pull(data) %>% map_chr(~ .x %>% class) %in% 
+	      c("int", "dbl", "numeric") %>% which %>% length %>%
+	      gt( palette_annotation$continuous %>% length) ~
+	      stop("tidyHeatmap says: Your continuous annotaton columns are bigger than the palette available"),
+	    ~ (.)
+	  )
       
   
 }
 
+#' @importFrom grid unit
 get_group_annotation = function(.data, .column, .row, .abundance, palette_annotation){
   
   # Comply with CRAN NOTES
@@ -808,8 +823,9 @@ get_group_annotation = function(.data, .column, .row, .abundance, palette_annota
         ct = anno_block(  
           gp = gpar(fill = palette_fill_row ),
           labels = row_split %>% unique %>% sort,
-          labels_gp = gpar(col = palette_text_row),
-          which = "row"
+          labels_gp = gpar(col = palette_text_row, fontsize = 8),
+          which = "row",
+          width = unit(9, "pt")
         )
       )
     
@@ -853,8 +869,9 @@ get_group_annotation = function(.data, .column, .row, .abundance, palette_annota
           ct = anno_block(  
             gp = gpar(fill = palette_fill_column ),
             labels = col_split %>% unique %>% sort,
-            labels_gp = gpar(col = palette_text_column),
-            which = "column"
+            labels_gp = gpar(col = palette_text_column, fontsize = 8),
+            which = "column",
+            height = unit(9, "pt")
           )
         )
       
@@ -1059,15 +1076,31 @@ annot_to_list = function(.data){
   # Comply with CRAN NOTES
   col_name = NULL
   annot = NULL
+  value = NULL
+  my_cells = NULL
+  name = NULL
+  data = NULL
   
-  .data %>% pull(annot) %>% setNames(.data %>% pull(col_name))  %>%
+  
+  .data %>% 
+  	pull(annot) %>%
+  	setNames(.data %>% pull(col_name))  %>%
     
     # If list is populated
     when(length(.) > 0 ~ (.) %>% c(
       col = list(.data %>%
                    filter(map_lgl(color, ~ .x %>% is.null %>% not)) %>%
                    { setNames( pull(., color),  pull(., col_name))    })
-    ), ~ (.))
+    ) %>%
+    	
+    	# Add additional arguments
+    	c(
+    		.data %>% 
+    			pull(further_arguments) %>% 
+    			combine_elements_with_the_same_name()
+    	),
+    
+    ~ (.)) 
     
 }
 
@@ -1095,3 +1128,75 @@ not = function(is){	!is }
 
 # Raise to the power
 pow = function(a,b){	a^b }
+
+#' @importFrom purrr map_dfr
+#' @importFrom purrr reduce
+#' @importFrom tibble enframe
+#' @importFrom grid unit.c
+combine_elements_with_the_same_name = function(x){
+	
+	# Fix CRAN notes
+	my_class  = NULL
+	value = NULL
+	name = NULL
+	data = NULL
+	
+	if(length(unlist(x))==0) return(unlist(x))
+	else {
+		list_df = 
+			map_dfr(x, ~ enframe(.x)) %>% 
+			mutate(my_class = map_chr(value, ~class(.x)[[1]])) 
+		
+		# The current backend does not allow multiple tails sizes
+		if(
+			list_df %>% 
+				filter(my_class == "simpleUnit") %>% 
+				nrow()  %>% 
+				gt(1) &&
+			list_df %>% 
+				filter(my_class == "simpleUnit") %>% 
+				pull(value) %>% 
+				reduce(identical) %>% 
+				not()
+		)
+			warning("tidyHeatmap says: the current backend only allows for one tail annotation size. The latter one will be selected.")
+			
+		# Select one size
+		list_df =  
+			bind_rows(
+			list_df %>% 
+				filter(my_class == "simpleUnit") %>% 
+				tail(1),
+			list_df %>% 
+				filter(my_class != "simpleUnit")
+		) %>% 
+			nest(data = -c(name, my_class)) %>% 
+			mutate(vector = map2(
+				data, my_class,
+				~ {
+					if(.y == "simpleUnit") reduce(.x$value, unit.c)
+					else if(.y == "gpar") combine_lists_with_the_same_name(.x$value) %>% as.list() %>% do.call(gpar, .)
+					else reduce(.x$value, c)
+				}
+			)) 
+		
+			
+		list_df %>% 
+			pull(vector) %>% 
+			setNames(list_df$name)
+			
+		# x = unlist(x)
+		# tapply(unlist(x, use.names = FALSE), rep(names(x), lengths(x)), FUN = c)
+	}
+
+}
+
+combine_lists_with_the_same_name = function(x){
+	
+	if(length(unlist(x))==0) return(unlist(x))
+	else {
+		x = unlist(x)
+		tapply(unlist(x, use.names = FALSE), rep(names(x), lengths(x)), FUN = c)
+	}
+	
+}
